@@ -1,10 +1,10 @@
-__version__ = "0.1.17"
+__version__ = "0.1.18"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.17)'
+__git_branch__ = '(detached from v0.1.18)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '5d996f59e36f5235d969e3c0b252ced74b0a191e'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '69097e4a8dc4f27d146935aa63268d8150b841e3'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
